#Toncalculator 
It is a simple calulator for addition, subtraction, multiplication,division, squire, to the power, sqire root, log, factorial, sin, cos, tan, cot, sec, cosec, nCr etc.
###There are many mathmatical conversions
```python
def add(x,y):
    #return x additioned by y
    return x+y

def sub(x,y):
    #return x subtract by y
    return x-y

def mul(x,y):
    #reurn x multiplied by y
    return x*y

def dev(x,y):
    #return x divided by y
    return x/y

def squire(x):
    #return squire of x
    return x*x
```